/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package helloworld;

import org.objectweb.dream.PushException;
import org.objectweb.dream.control.activity.Util;
import org.objectweb.dream.message.ChunkFactoryReference;
import org.objectweb.dream.message.Message;
import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Basic Client implementation, using two mono-threaded tasks.
 */
public class ClientImpl extends AbstractClientImpl
{
  /** Default constructor */
  public ClientImpl()
  {
    fcNeedAsyncStart = true;
  }

  // -------------------------------------------------------------------------
  // Overridden methods
  // -------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.AbstractComponent#startFc()
   */
  public void startFc() throws IllegalLifeCycleException
  {
    super.startFc();
    Message msg = messageManager.createMessage();
    ChunkFactoryReference<HelloWorldChunk> chunkFactory = messageManager.getChunkFactory(HelloWorldChunk.class);
    HelloWorldChunk chunk = messageManager.createChunk(chunkFactory);
    chunk.setMessage("in start");
    messageManager.addChunk(msg, HelloWorldChunk.DEFAULT_NAME, chunk);
    try
    {
      outPushItf.push(msg);
    }
    catch (PushException e)
    {
      e.printStackTrace();
    }
  }

  /**
   * @see org.objectweb.dream.AbstractComponent#beforeFirstStart(Component)
   */
  protected void beforeFirstStart(Component componentItf)
      throws IllegalLifeCycleException
  {
    try
    {
      Util.addTask(componentItf, new ClientTask("Hello World task1"), null);
      Util.addTask(componentItf, new ClientTask("Hello World task2"), null);
      logger.log(BasicLevel.DEBUG, "tasks added");
    }
    catch (Exception e)
    {
      throw new IllegalLifeCycleException("Can't add task");
    }
  }
}
