/**
 * Dream Copyright (C) 2003-2004 INRIA Rhone-Alpes
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any
 * later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * Contact: dream@objectweb.org
 * 
 * Initial developer(s): Matthieu Leclercq 
 * Contributor(s):
 */

package org.objectweb.dream.control.activity.task;

import org.objectweb.fractal.api.control.NameController;

/**
 * Exception thrown by task controller when a given task component is unknown.
 */
public class NoSuchTaskException extends Exception
{

  private static final long serialVersionUID = 3690471424720973872L;

  Task                      task;

  /**
   * @param task a task.
   */
  public NoSuchTaskException(Task task)
  {
    this.task = task;
  }

  /**
   * @param task a task.
   * @param message a message.
   */
  public NoSuchTaskException(Task task, String message)
  {
    super(message);
    this.task = task;
  }

  /**
   * @return the task.
   */
  public Task getTask()
  {
    return task;
  }

  /**
   * @see java.lang.Throwable#toString()
   */
  public String toString()
  {
    if (task != null && task instanceof NameController)
    {
      return super.toString() + " task name : "
          + ((NameController) task).getFcName();
    }
    return super.toString();
  }
}