/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.task;

/**
 * A control interface used to activate or desactivate tasks of the component
 * (ie. register/unregister in activity manager). This interface is an hidden
 * control interface used by lifecycle controller or by task controller.
 */
public interface TaskActivationController
{

  /**
   * Register the given task with the activity manager. If the task is already
   * registered, do nothing.
   * 
   * @param task the task to register.
   * @throws NoSuchTaskException if the given task is unknown.
   * @throws IllegalTaskException if the task can't be registred in the activity
   *           manager.
   * @see org.objectweb.dream.control.activity.manager.TaskManager#registerTask(Task,
   *      java.util.Map)
   */
  void activateTask(Task task) throws NoSuchTaskException, IllegalTaskException;

  /**
   * Unregister the given task with the activity manager. This method will block
   * until the task is stopped and unregistered with the activity manager.
   * 
   * @param task the task to unregister.
   * @throws NoSuchTaskException if the given task is unknown.
   * @throws IllegalTaskException if the task can't be unregistred in the
   *           activity manager or if the task is not activated.
   * @see org.objectweb.dream.control.activity.manager.TaskManager#unregisterTask(Task)
   */
  void deactivateTask(Task task) throws NoSuchTaskException,
      IllegalTaskException;

  /**
   * Unregister the given task with the activity manager. This method returns
   * immediatly, and the given listener will be notify when the task stop
   * unregister with the activity manager. If the task is not activated, the
   * listener is immediatly notifyed and the method returns.
   * 
   * @param task the task to unregister.
   * @param taskStoppedListener the listener to notify.
   * @throws NoSuchTaskException if the given task is unknown.
   * @throws IllegalTaskException if the task can't be unregistred in the
   *           activity manager.
   * @see org.objectweb.dream.control.activity.manager.TaskManager#unregisterTask(Task)
   */
  void deactivateTask(Task task, TaskStoppedListener taskStoppedListener)
      throws NoSuchTaskException, IllegalTaskException;
}