/**
 * DREAM
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s):
 */

package org.objectweb.dream.control.binding;

import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.BindingController;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * A component interface to control the bindings of the component to which it
 * belongs. It is implicitely assumed here that the component's type system
 * makes a distinction between "client" and "server" interfaces. This interface
 * extends the {@link BindingController}interface with a method allowing the
 * binding of two components with associated contextual information.
 */
public interface ContextualBindingController extends BindingController
{

  /**
   * Binds the client interface whose name is given to a server interface. More
   * precisely, binds the client interface of the component to which this
   * interface belongs, and whose name is equal to the given name, to the given
   * server interface. The given server interface must be in the same address
   * space as the client interface. Contextual information can be given using
   * the <code>hints</code> parameter.
   * 
   * @param clientItfName the name of a client interface of the component to
   *          which this interface belongs.
   * @param serverItf a server interface.
   * @param hints contextual information.
   * @throws NoSuchInterfaceException if there is no such client interface.
   * @throws IllegalBindingException if the binding cannot be created.
   * @throws IllegalLifeCycleException if this component has a {@link
   *           org.objectweb.fractal.api.control.LifeCycleController} interface,
   *           but it is not in an appropriate state to perform this operation.
   */

  void bindFc(String clientItfName, Object serverItf, Object hints)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException;
}