/**
 * Dream Copyright (C) 2003-2004 INRIA Rhone-Alpes
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any
 * later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * Contact: dream@objectweb.org
 * 
 * Initial developer(s): Matthieu Leclercq 
 * Contributor(s):
 */

package org.objectweb.dream.control.lifecycle;

import org.objectweb.dream.control.logger.Loggable;
import org.objectweb.dream.control.logger.LoggerController;
import org.objectweb.dream.control.logger.LoggerControllerRegister;
import org.objectweb.dream.util.NullLogger;
import org.objectweb.fractal.api.factory.InstantiationException;
import org.objectweb.fractal.julia.InitializationContext;
import org.objectweb.util.monolog.api.Logger;

/**
 * Basic mixin implementing the <code>Loggable</code> interface, and provides
 * a logger to the LifeCycleController. <br>
 * <br>
 * <b>Requirements </b>
 * <ul>
 * <li>this mixin requires the
 * {@link org.objectweb.dream.control.logger.UseLoggerControllerMixin }mixin.
 * </li>
 * </ul>
 */
public abstract class LoggableLifeCycleMixin implements Loggable
{

  /** The logger of the task controller */
  public Logger weaveableLCCLogger;

  /**
   * @see org.objectweb.fractal.julia.Controller#initFcController(InitializationContext)
   */
  public void initFcController(final InitializationContext ic)
      throws InstantiationException
  {
    _super_initFcController(ic);

    // Set the lifeCycleLogger
    weaveableLCCLogger = NullLogger.NULL_LOGGER;
    // register to logger controller
    if (_this_weaveableOptLogC != null)
    {
      ((LoggerControllerRegister) _this_weaveableOptLogC).register(
          "life-cycle", this);
    }
  }

  /**
   * @see Loggable#setLogger(String, Logger)
   */
  public void setLogger(String name, Logger logger)
  {
    if ("life-cycle".equals(name))
    {
      weaveableLCCLogger = logger;
    }
  }

  // ---------------------------------------------------------------------------
  // Fields and methods required by the mixin class in the base class
  // ---------------------------------------------------------------------------

  /**
   * The <tt>weaveableOptLogC</tt> field required by this mixin. This field is
   * supposed to reference the {@link LoggerController }interface of the
   * component to which this controller object belongs.
   */
  public LoggerController _this_weaveableOptLogC;

  /**
   * The
   * {@link org.objectweb.fractal.julia.Controller#initFcController(InitializationContext)}
   * method overridden by this mixin.
   * 
   * @see org.objectweb.fractal.julia.Controller#initFcController(InitializationContext)
   */
  public abstract void _super_initFcController(InitializationContext ic)
      throws InstantiationException;

}