/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.pool;

import java.lang.ref.Reference;

/**
 * This interface defines a method to recycle an object.
 */
public interface Recyclable
{
  /**
   * Recycles the object. This consists in reseting all the fields of the
   * object, <b>except</b> the reference field.
   */
  void recycle();

  /**
   * Sets a {@link Reference} object that can be used by object pool
   * implementation. This field must <b>not</b> be erase by the
   * {@link #recycle()} method.
   * 
   * @param reference a {@link Reference} object that can be used by object pool
   *          implementation.
   */
  void setReference(Reference< ? extends Recyclable> reference);

  /**
   * Returns the reference object set by the {@link #setReference(Reference)}
   * method.
   * 
   * @return a {@link Reference} object that can be used by object pool
   *         implementation.
   */
  Reference< ? extends Recyclable> getReference();
}
